/**
 * Copyright (C) 2010 Daniel Manzke <daniel.manzke@googlemail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.devsurf.injection.guice.integrations.rocoto;

import com.google.inject.AbstractModule;
import com.google.inject.Inject;
import com.google.inject.Singleton;
import com.googlecode.rocoto.simpleconfig.SimpleConfigurationModule;

import de.devsurf.injection.guice.scanner.InstallationContext.BindingStage;
import de.devsurf.injection.guice.scanner.annotations.GuiceModule;

/**
 * Module, which will be installed automatically. While being installed, this
 * Module will install the Rocoto-Configuration Module, so all loaded Key/Values
 * will be bound, too.
 * 
 * @author Daniel Manzke
 * 
 */
@GuiceModule(stage = BindingStage.BUILD)
public class ConfigurationModuleInstaller extends AbstractModule {
    @Inject
    private ExtendedConfigurationModule module;

    @Override
    protected void configure() {
	binder().install(module);
    }

    @Singleton
    public static class ExtendedConfigurationModule extends SimpleConfigurationModule {
    }
}
